#!/usr/bin/env python
"""
Command line utility to dump the ASCII or EBCDIC

     Copyright (C) 2005  Kurt Schwehr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

$Id: segytextheader.py,v 1.5 2005/10/13 20:31:49 schwehr Exp $

"""

# These values end up in the pydoc web page
__version__ = '$Revision: 1.5 $'.split()[1] # See man ident
__date__ = '$Date: 2005/10/13 20:31:49 $'.split()[1]
__author__ = 'Kurt Schwehr'
__credits__ = """Nothing happens in a vacuum"""

from segy import Segy
import segy
import sqlite
import os
import sys

from optparse import OptionParser

from segy_version import VERSION

myparser = OptionParser(usage="%prog [options] segyfile1 segyfile2 ... segyfileN",
                      version="%prog "+VERSION+' - '+__version__)
myparser.add_option('-e','--ebcdic',dest='ebcdic',action="store_true",default=False,
		    help='')
myparser.add_option('-d','--driver',dest="drv",
                  help="specify which driver to parse data file.  [default: %default]",
                  default="segy_drv_rev1")

myparser.add_option('-w','--warn-only',action="store_true",dest='warnOnly',default=False,
                    help='Allow processing to continue in certain error conditions. [default: %default]')

# FIX: TESTING ONLY
myparser.add_option('-H','--histogram',action="store_true",dest='histogram',default=False,
                    help='Write a histogram of the character codes in the header. [default: %default]')


from verbosity import BOMBASTIC,VERBOSE,TRACE,TERSE,ALWAYS
import verbosity
verbosity.addVerbosityOptions(myparser)


def dumpHistogram(data, outfile='hist.dat', min=0, max=255):
    """Histogram the values in a buffer.  This is for exploring the difference between ebcdic and ascii"""
    hist = {}
    #print data
    for i in range(min,max+1):
        hist[i] = 0
    print len(data)
    for i in range(len(data)):
        c = ord(data[i])
        hist[c] = hist[c]+1
    out = open (outfile,'w')
    for i in range(min,max+1):
        out.write(str(i)+' '+str(hist[i])+'\n')
    out.close()
    return

if __name__ == "__main__":
    (options,args) = myparser.parse_args()
    if options.verbosity>= VERBOSE:
        print "verbosity = ", verbostiy
    for filename in args:
        if options.verbosity>=TRACE:
            print "FILENAME: ",filename
        segyfile = None
        try: 
            segyfile = Segy(filename,drivername=options.drv)
        except ValueError:
            # FIX: make this optional as to warn or actually fail
            print "ERROR: Failed to open ",filename
            if not options.warnOnly:
                sys.exit("  -w not specified.  QUITTING..")
            else:
                print "  will keep on going (-w specified)"
                continue

        # pull in the header.

        headerStr = segyfile.header.getTextFileBlock()
        if options.histogram: dumpHistogram(outfile='hist.dat', data=headerStr, min=0, max=255)
        if options.ebcdic:
            print "ebcdic 2 ascii"
            import ebcdic
            headerStr = ebcdic.EbcdicToAscii(headerStr)
        #else:
        print headerStr
        
